#! /bin/sh
# This is a shell archive.  Remove anything before this line, then unpack
# it by saving it into a file and typing "sh file".  To overwrite existing
# files, type "sh file -c".  You can also feed this as standard input via
# unshar, or by typing "sh <file", e.g..  If this archive is complete, you
# will see the following message at the end:
#		"End of archive 2 (of 2)."
# Contents:  gabriel-scheme/boyer.sch gabriel-scheme/fprint.tst
#   gabriel-scheme/takr.sch
# Wrapped by oz@yunexus on Thu May  2 23:11:10 1991
PATH=/bin:/usr/bin:/usr/ucb ; export PATH
if test -f 'gabriel-scheme/boyer.sch' -a "${1}" != "-c" ; then 
  echo shar: Will not clobber existing file \"'gabriel-scheme/boyer.sch'\"
else
echo shar: Extracting \"'gabriel-scheme/boyer.sch'\" \(20075 characters\)
sed "s/^X//" >'gabriel-scheme/boyer.sch' <<'END_OF_FILE'
X;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
X; File:         boyer.sch
X; Description:  The Boyer benchmark
X; Author:       Bob Boyer
X; Created:      5-Apr-85
X; Modified:     10-Apr-85 14:52:20 (Bob Shaw)
X;               22-Jul-87 (Will Clinger)
X; Language:     Scheme (but see note)
X; Status:       Public Domain
X;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
X
X; Note:  This benchmark uses property lists.  The procedures that must
X; be supplied are get and put, where (put x y z) is equivalent to Common
X; Lisp's (setf (get x y) z).
X; Note:  The Common Lisp version of this benchmark returns the wrong
X; answer because it uses the Common Lisp equivalent of memv instead of
X; member in the falsep and truep procedures.  (The error arose because
X; memv is called member in Common Lisp.  Don't ask what member is called,
X; unless you want to learn about keyword arguments.)  This Scheme version
X; may run a few percent slower than it would if it were equivalent to
X; the Common Lisp version, but it works.
X
X;;; BOYER -- Logic programming benchmark, originally written by Bob Boyer.
X;;; Fairly CONS intensive.
X
X(define unify-subst 0)
X(define temp-temp 0)
X
X(define (add-lemma term)
X  (cond ((and (pair? term)
X              (eq? (car term)
X                   (quote equal))
X              (pair? (cadr term)))
X         (put (car (cadr term))
X              (quote lemmas)
X              (cons term (get (car (cadr term)) (quote lemmas)))))
X        (else (error "ADD-LEMMA did not like term:  " term))))
X
X(define (add-lemma-lst lst)
X  (cond ((null? lst)
X         #t)
X        (else (add-lemma (car lst))
X              (add-lemma-lst (cdr lst)))))
X
X(define (apply-subst alist term)
X  (cond ((not (pair? term))
X         (cond ((begin (set! temp-temp (assq term alist))
X                       temp-temp)
X                (cdr temp-temp))
X               (else term)))
X        (else (cons (car term)
X                    (apply-subst-lst alist (cdr term))))))
X
X(define (apply-subst-lst alist lst)
X  (cond ((null? lst)
X         #f)
X        (else (cons (apply-subst alist (car lst))
X                    (apply-subst-lst alist (cdr lst))))))
X
X(define (falsep x lst)
X  (or (equal? x (quote (f)))
X      (member x lst)))
X
X(define (one-way-unify term1 term2)
X  (begin (set! unify-subst #f)
X         (one-way-unify1 term1 term2)))
X
X(define (one-way-unify1 term1 term2)
X  (cond ((not (pair? term2))
X         (cond ((begin (set! temp-temp (assq term2 unify-subst))
X                       temp-temp)
X                (equal? term1 (cdr temp-temp)))
X               (else (set! unify-subst (cons (cons term2 term1)
X                                             unify-subst))
X                     #t)))
X        ((not (pair? term1))
X         #f)
X        ((eq? (car term1)
X              (car term2))
X         (one-way-unify1-lst (cdr term1)
X                             (cdr term2)))
X        (else #f)))
X
X(define (one-way-unify1-lst lst1 lst2)
X  (cond ((null? lst1)
X         #t)
X        ((one-way-unify1 (car lst1)
X                         (car lst2))
X         (one-way-unify1-lst (cdr lst1)
X                             (cdr lst2)))
X        (else #f)))
X
X(define (rewrite term)
X  (cond ((not (pair? term))
X         term)
X        (else (rewrite-with-lemmas (cons (car term)
X                                         (rewrite-args (cdr term)))
X                                   (get (car term)
X                                        (quote lemmas))))))
X
X(define (rewrite-args lst)
X  (cond ((null? lst)
X         #f)
X        (else (cons (rewrite (car lst))
X                    (rewrite-args (cdr lst))))))
X
X(define (rewrite-with-lemmas term lst)
X  (cond ((null? lst)
X         term)
X        ((one-way-unify term (cadr (car lst)))
X         (rewrite (apply-subst unify-subst (caddr (car lst)))))
X        (else (rewrite-with-lemmas term (cdr lst)))))
X
X(define (setup)
X  (add-lemma-lst
X   (quote ((equal (compile form)
X                  (reverse (codegen (optimize form)
X                                    (nil))))
X           (equal (eqp x y)
X                  (equal (fix x)
X                         (fix y)))
X           (equal (greaterp x y)
X                  (lessp y x))
X           (equal (lesseqp x y)
X                  (not (lessp y x)))
X           (equal (greatereqp x y)
X                  (not (lessp x y)))
X           (equal (boolean x)
X                  (or (equal x (t))
X                      (equal x (f))))
X           (equal (iff x y)
X                  (and (implies x y)
X                       (implies y x)))
X           (equal (even1 x)
X                  (if (zerop x)
X                      (t)
X                      (odd (1- x))))
X           (equal (countps- l pred)
X                  (countps-loop l pred (zero)))
X           (equal (fact- i)
X                  (fact-loop i 1))
X           (equal (reverse- x)
X                  (reverse-loop x (nil)))
X           (equal (divides x y)
X                  (zerop (remainder y x)))
X           (equal (assume-true var alist)
X                  (cons (cons var (t))
X                        alist))
X           (equal (assume-false var alist)
X                  (cons (cons var (f))
X                        alist))
X           (equal (tautology-checker x)
X                  (tautologyp (normalize x)
X                              (nil)))
X           (equal (falsify x)
X                  (falsify1 (normalize x)
X                            (nil)))
X           (equal (prime x)
X                  (and (not (zerop x))
X                       (not (equal x (add1 (zero))))
X                       (prime1 x (1- x))))
X           (equal (and p q)
X                  (if p (if q (t)
X                              (f))
X                        (f)))
X           (equal (or p q)
X                  (if p (t)
X                        (if q (t)
X                              (f))
X                        (f)))
X           (equal (not p)
X                  (if p (f)
X                        (t)))
X           (equal (implies p q)
X                  (if p (if q (t)
X                              (f))
X                        (t)))
X           (equal (fix x)
X                  (if (numberp x)
X                      x
X                      (zero)))
X           (equal (if (if a b c)
X                      d e)
X                  (if a (if b d e)
X                        (if c d e)))
X           (equal (zerop x)
X                  (or (equal x (zero))
X                      (not (numberp x))))
X           (equal (plus (plus x y)
X                        z)
X                  (plus x (plus y z)))
X           (equal (equal (plus a b)
X                         (zero))
X                  (and (zerop a)
X                       (zerop b)))
X           (equal (difference x x)
X                  (zero))
X           (equal (equal (plus a b)
X                         (plus a c))
X                  (equal (fix b)
X                         (fix c)))
X           (equal (equal (zero)
X                         (difference x y))
X                  (not (lessp y x)))
X           (equal (equal x (difference x y))
X                  (and (numberp x)
X                       (or (equal x (zero))
X                           (zerop y))))
X           (equal (meaning (plus-tree (append x y))
X                           a)
X                  (plus (meaning (plus-tree x)
X                                 a)
X                        (meaning (plus-tree y)
X                                 a)))
X           (equal (meaning (plus-tree (plus-fringe x))
X                           a)
X                  (fix (meaning x a)))
X           (equal (append (append x y)
X                          z)
X                  (append x (append y z)))
X           (equal (reverse (append a b))
X                  (append (reverse b)
X                          (reverse a)))
X           (equal (times x (plus y z))
X                  (plus (times x y)
X                        (times x z)))
X           (equal (times (times x y)
X                         z)
X                  (times x (times y z)))
X           (equal (equal (times x y)
X                         (zero))
X                  (or (zerop x)
X                      (zerop y)))
X           (equal (exec (append x y)
X                        pds envrn)
X                  (exec y (exec x pds envrn)
X                          envrn))
X           (equal (mc-flatten x y)
X                  (append (flatten x)
X                          y))
X           (equal (member x (append a b))
X                  (or (member x a)
X                      (member x b)))
X           (equal (member x (reverse y))
X                  (member x y))
X           (equal (length (reverse x))
X                  (length x))
X           (equal (member a (intersect b c))
X                  (and (member a b)
X                       (member a c)))
X           (equal (nth (zero)
X                       i)
X                  (zero))
X           (equal (exp i (plus j k))
X                  (times (exp i j)
X                         (exp i k)))
X           (equal (exp i (times j k))
X                  (exp (exp i j)
X                       k))
X           (equal (reverse-loop x y)
X                  (append (reverse x)
X                          y))
X           (equal (reverse-loop x (nil))
X                  (reverse x))
X           (equal (count-list z (sort-lp x y))
X                  (plus (count-list z x)
X                        (count-list z y)))
X           (equal (equal (append a b)
X                         (append a c))
X                  (equal b c))
X           (equal (plus (remainder x y)
X                        (times y (quotient x y)))
X                  (fix x))
X           (equal (power-eval (big-plus1 l i base)
X                              base)
X                  (plus (power-eval l base)
X                        i))
X           (equal (power-eval (big-plus x y i base)
X                              base)
X                  (plus i (plus (power-eval x base)
X                                (power-eval y base))))
X           (equal (remainder y 1)
X                  (zero))
X           (equal (lessp (remainder x y)
X                         y)
X                  (not (zerop y)))
X           (equal (remainder x x)
X                  (zero))
X           (equal (lessp (quotient i j)
X                         i)
X                  (and (not (zerop i))
X                       (or (zerop j)
X                           (not (equal j 1)))))
X           (equal (lessp (remainder x y)
X                         x)
X                  (and (not (zerop y))
X                       (not (zerop x))
X                       (not (lessp x y))))
X           (equal (power-eval (power-rep i base)
X                              base)
X                  (fix i))
X           (equal (power-eval (big-plus (power-rep i base)
X                                        (power-rep j base)
X                                        (zero)
X                                        base)
X                              base)
X                  (plus i j))
X           (equal (gcd x y)
X                  (gcd y x))
X           (equal (nth (append a b)
X                       i)
X                  (append (nth a i)
X                          (nth b (difference i (length a)))))
X           (equal (difference (plus x y)
X                              x)
X                  (fix y))
X           (equal (difference (plus y x)
X                              x)
X                  (fix y))
X           (equal (difference (plus x y)
X                              (plus x z))
X                  (difference y z))
X           (equal (times x (difference c w))
X                  (difference (times c x)
X                              (times w x)))
X           (equal (remainder (times x z)
X                             z)
X                  (zero))
X           (equal (difference (plus b (plus a c))
X                              a)
X                  (plus b c))
X           (equal (difference (add1 (plus y z))
X                              z)
X                  (add1 y))
X           (equal (lessp (plus x y)
X                         (plus x z))
X                  (lessp y z))
X           (equal (lessp (times x z)
X                         (times y z))
X                  (and (not (zerop z))
X                       (lessp x y)))
X           (equal (lessp y (plus x y))
X                  (not (zerop x)))
X           (equal (gcd (times x z)
X                       (times y z))
X                  (times z (gcd x y)))
X           (equal (value (normalize x)
X                         a)
X                  (value x a))
X           (equal (equal (flatten x)
X                         (cons y (nil)))
X                  (and (nlistp x)
X                       (equal x y)))
X           (equal (listp (gopher x))
X                  (listp x))
X           (equal (samefringe x y)
X                  (equal (flatten x)
X                         (flatten y)))
X           (equal (equal (greatest-factor x y)
X                         (zero))
X                  (and (or (zerop y)
X                           (equal y 1))
X                       (equal x (zero))))
X           (equal (equal (greatest-factor x y)
X                         1)
X                  (equal x 1))
X           (equal (numberp (greatest-factor x y))
X                  (not (and (or (zerop y)
X                                (equal y 1))
X                            (not (numberp x)))))
X           (equal (times-list (append x y))
X                  (times (times-list x)
X                         (times-list y)))
X           (equal (prime-list (append x y))
X                  (and (prime-list x)
X                       (prime-list y)))
X           (equal (equal z (times w z))
X                  (and (numberp z)
X                       (or (equal z (zero))
X                           (equal w 1))))
X           (equal (greatereqpr x y)
X                  (not (lessp x y)))
X           (equal (equal x (times x y))
X                  (or (equal x (zero))
X                      (and (numberp x)
X                           (equal y 1))))
X           (equal (remainder (times y x)
X                             y)
X                  (zero))
X           (equal (equal (times a b)
X                         1)
X                  (and (not (equal a (zero)))
X                       (not (equal b (zero)))
X                       (numberp a)
X                       (numberp b)
X                       (equal (1- a)
X                              (zero))
X                       (equal (1- b)
X                              (zero))))
X           (equal (lessp (length (delete x l))
X                         (length l))
X                  (member x l))
X           (equal (sort2 (delete x l))
X                  (delete x (sort2 l)))
X           (equal (dsort x)
X                  (sort2 x))
X           (equal (length (cons x1
X                                (cons x2
X                                      (cons x3 (cons x4
X                                                     (cons x5
X                                                           (cons x6 x7)))))))
X                  (plus 6 (length x7)))
X           (equal (difference (add1 (add1 x))
X                              2)
X                  (fix x))
X           (equal (quotient (plus x (plus x y))
X                            2)
X                  (plus x (quotient y 2)))
X           (equal (sigma (zero)
X                         i)
X                  (quotient (times i (add1 i))
X                            2))
X           (equal (plus x (add1 y))
X                  (if (numberp y)
X                      (add1 (plus x y))
X                      (add1 x)))
X           (equal (equal (difference x y)
X                         (difference z y))
X                  (if (lessp x y)
X                      (not (lessp y z))
X                      (if (lessp z y)
X                          (not (lessp y x))
X                          (equal (fix x)
X                                 (fix z)))))
X           (equal (meaning (plus-tree (delete x y))
X                           a)
X                  (if (member x y)
X                      (difference (meaning (plus-tree y)
X                                           a)
X                                  (meaning x a))
X                      (meaning (plus-tree y)
X                               a)))
X           (equal (times x (add1 y))
X                  (if (numberp y)
X                      (plus x (times x y))
X                      (fix x)))
X           (equal (nth (nil)
X                       i)
X                  (if (zerop i)
X                      (nil)
X                      (zero)))
X           (equal (last (append a b))
X                  (if (listp b)
X                      (last b)
X                      (if (listp a)
X                          (cons (car (last a))
X                                b)
X                          b)))
X           (equal (equal (lessp x y)
X                         z)
X                  (if (lessp x y)
X                      (equal t z)
X                      (equal f z)))
X           (equal (assignment x (append a b))
X                  (if (assignedp x a)
X                      (assignment x a)
X                      (assignment x b)))
X           (equal (car (gopher x))
X                  (if (listp x)
X                      (car (flatten x))
X                      (zero)))
X           (equal (flatten (cdr (gopher x)))
X                  (if (listp x)
X                      (cdr (flatten x))
X                      (cons (zero)
X                            (nil))))
X           (equal (quotient (times y x)
X                            y)
X                  (if (zerop y)
X                      (zero)
X                      (fix x)))
X           (equal (get j (set i val mem))
X                  (if (eqp j i)
X                      val
X                      (get j mem)))))))
X
X(define (tautologyp x true-lst false-lst)
X  (cond ((truep x true-lst)
X         #t)
X        ((falsep x false-lst)
X         #f)
X        ((not (pair? x))
X         #f)
X        ((eq? (car x)
X              (quote if))
X         (cond ((truep (cadr x)
X                       true-lst)
X                (tautologyp (caddr x)
X                            true-lst false-lst))
X               ((falsep (cadr x)
X                        false-lst)
X                (tautologyp (cadddr x)
X                            true-lst false-lst))
X               (else (and (tautologyp (caddr x)
X                                      (cons (cadr x)
X                                            true-lst)
X                                      false-lst)
X                          (tautologyp (cadddr x)
X                                      true-lst
X                                      (cons (cadr x)
X                                            false-lst))))))
X        (else #f)))
X
X(define (tautp x)
X  (tautologyp (rewrite x)
X              #f #f))
X
X(define (test)
X  (define ans #f)
X  (define term #f)
X  (set! term
X        (apply-subst
X         (quote ((x f (plus (plus a b)
X                            (plus c (zero))))
X                 (y f (times (times a b)
X                             (plus c d)))
X                 (z f (reverse (append (append a b)
X                                       (nil))))
X                 (u equal (plus a b)
X                          (difference x y))
X                 (w lessp (remainder a b)
X                          (member a (length b)))))
X         (quote (implies (and (implies x y)
X                              (and (implies y z)
X                                   (and (implies z u)
X                                        (implies u w))))
X                         (implies x w)))))
X  (set! ans (tautp term))
X  ans)
X
X(define (trans-of-implies n)
X  (list (quote implies)
X        (trans-of-implies1 n)
X        (list (quote implies)
X              0 n)))
X
X(define (trans-of-implies1 n)
X  (cond ((equal? n 1)
X         (list (quote implies)
X               0 1))
X        (else (list (quote and)
X                    (list (quote implies)
X                          (- n 1)
X                          n)
X                    (trans-of-implies1 (- n 1))))))
X
X(define (truep x lst)
X  (or (equal? x (quote (t)))
X      (member x lst)))
X
X(setup)
X
X;;; make sure you've run (setup) then call:  (test)
X
X(run-benchmark "Boyer" (lambda () (test)))
X
END_OF_FILE
if test 20075 -ne `wc -c <'gabriel-scheme/boyer.sch'`; then
    echo shar: \"'gabriel-scheme/boyer.sch'\" unpacked with wrong size!
fi
# end of 'gabriel-scheme/boyer.sch'
fi
if test -f 'gabriel-scheme/fprint.tst' -a "${1}" != "-c" ; then 
  echo shar: Will not clobber existing file \"'gabriel-scheme/fprint.tst'\"
else
echo shar: Extracting \"'gabriel-scheme/fprint.tst'\" \(17117 characters\)
sed "s/^X//" >'gabriel-scheme/fprint.tst' <<'END_OF_FILE'
X
X((((((678901fg 567890ef 567890ef 456789de 456789de 345678cd) 234567bc (567890ef 456789de 456789de 345678cd 345678cd 234567bc) 123456ab (456789de 345678cd 345678cd 234567bc 234567bc 123456ab) xyzabc34) wxyzab23 ((567890ef 456789de 456789de 345678cd 345678cd 234567bc) 123456ab (456789de 345678cd 345678cd 234567bc 234567bc 123456ab) xyzabc34 (345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23) uvwxyz12 ((456789de 345678cd 345678cd 234567bc 234567bc 123456ab) xyzabc34 (345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12) stuvwx01) qrstuv90 (((567890ef 456789de 456789de 345678cd 345678cd 234567bc) 123456ab (456789de 345678cd 345678cd 234567bc 234567bc 123456ab) xyzabc34 (345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23) uvwxyz12 ((456789de 345678cd 345678cd 234567bc 234567bc 123456ab) xyzabc34 (345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab2X3) uvwxyz12) stuvwx01 ((345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01) qrstuv90) opqrst89 (((456789de 345678cd 345678cd 234567bc 234567bc 123456ab) xyzabc34 (345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12) stuvwx01 ((345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01) qrstuv90 ((234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90) opqrst89) mnopqr78) klmnop67 ((((567890ef 456789de 456789de 345678cd 345678cd 234567bc) 123456ab (456789de 345678cd 345678cd 234567bc 234567bc 123456ab) xyzabc34 (345678cd 234X567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23) uvwxyz12 ((456789de 345678cd 345678cd 234567bc 234567bc 123456ab) xyzabc34 (345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12) stuvwx01 ((345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01) qrstuv90) opqrst89 (((456789de 345678cd 345678cd 234567bc 234567bc 123456ab) xyzabc34 (345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12) stuvwx01 ((345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01) qrstuv90 ((234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvXwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90) opqrst89) mnopqr78 (((345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01) qrstuv90 ((234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90) opqrst89 ((123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89) mnopqr78) klmnop67) ijklmn56 ((((456789de 345678cd 345678cd 234567bc 234567bc 123456ab) xyzabc34 (345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12) stuvwx01 ((345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 1X23456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01) qrstuv90 ((234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90) opqrst89) mnopqr78 (((345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01) qrstuv90 ((234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90) opqrst89 ((123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89) mnopqr78) klmnop67 (((234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) Xuvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90) opqrst89 ((123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89) mnopqr78 ((xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89 (uvwxyz12 stuvwx01 stuvwx01 qrstuv90 qrstuv90 opqrst89) mnopqr78) klmnop67) ijklmn56) ghijkl45) efghij34 (((((567890ef 456789de 456789de 345678cd 345678cd 234567bc) 123456ab (456789de 345678cd 345678cd 234567bc 234567bc 123456ab) xyzabc34 (345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23) uvwxyz12 ((456789de 345678cd 345678cd 234567bc 234567bc 123456ab) xyzabc34 (345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12) stuvwx01 ((345678cd 234567Xbc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01) qrstuv90) opqrst89 (((456789de 345678cd 345678cd 234567bc 234567bc 123456ab) xyzabc34 (345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12) stuvwx01 ((345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01) qrstuv90 ((234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90) opqrst89) mnopqr78 (((345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx0X1) qrstuv90 ((234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90) opqrst89 ((123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89) mnopqr78) klmnop67) ijklmn56 ((((456789de 345678cd 345678cd 234567bc 234567bc 123456ab) xyzabc34 (345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12) stuvwx01 ((345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01) qrstuv90 ((234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyzX12 uvwxyz12 stuvwx01) qrstuv90) opqrst89) mnopqr78 (((345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01) qrstuv90 ((234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90) opqrst89 ((123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89) mnopqr78) klmnop67 (((234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90) opqrst89 ((123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzXab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89) mnopqr78 ((xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89 (uvwxyz12 stuvwx01 stuvwx01 qrstuv90 qrstuv90 opqrst89) mnopqr78) klmnop67) ijklmn56) ghijkl45 ((((345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01) qrstuv90 ((234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90) opqrst89 ((123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89) mnopqr78) klmnop67 (((234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxXyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90) opqrst89 ((123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89) mnopqr78 ((xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89 (uvwxyz12 stuvwx01 stuvwx01 qrstuv90 qrstuv90 opqrst89) mnopqr78) klmnop67) ijklmn56 (((123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89) mnopqr78 ((xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89 (uvwxyz12 stuvwx01 stuvwx01 qrstuv90 qrstuv90 opqrst89) mnopqr78) klmnop67 ((wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89 (uvwxyz12 stXuvwx01 stuvwx01 qrstuv90 qrstuv90 opqrst89) mnopqr78 (stuvwx01 qrstuv90 qrstuv90 opqrst89 opqrst89 mnopqr78) klmnop67) ijklmn56) ghijkl45) efghij34) cdefgh23 (((((456789de 345678cd 345678cd 234567bc 234567bc 123456ab) xyzabc34 (345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12) stuvwx01 ((345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01) qrstuv90 ((234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90) opqrst89) mnopqr78 (((345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01) qrstuv90 ((234567bc 123456ab 123456aXb xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90) opqrst89 ((123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89) mnopqr78) klmnop67 (((234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90) opqrst89 ((123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89) mnopqr78 ((xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89 (uvwxyz12 stuvwx01 stuvwx01 qrstuv90 qrstuv90 opqrst89) mnopqr78) klmnop67) ijklmn56X) ghijkl45 ((((345678cd 234567bc 234567bc 123456ab 123456ab xyzabc34) wxyzab23 (234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01) qrstuv90 ((234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90) opqrst89 ((123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89) mnopqr78) klmnop67 (((234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90) opqrst89 ((123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx0X1 qrstuv90) opqrst89) mnopqr78 ((xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89 (uvwxyz12 stuvwx01 stuvwx01 qrstuv90 qrstuv90 opqrst89) mnopqr78) klmnop67) ijklmn56 (((123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89) mnopqr78 ((xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89 (uvwxyz12 stuvwx01 stuvwx01 qrstuv90 qrstuv90 opqrst89) mnopqr78) klmnop67 ((wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89 (uvwxyz12 stuvwx01 stuvwx01 qrstuv90 qrstuv90 opqrst89) mnopqr78 (stuvwx01 qrstuv90 qrstuv90 opqrst89 opqrst89 mnopqr78) klmnop67) ijklmn56) ghijkl45) efghij34 ((((234567bc 123456ab 123456ab xyzabc34 xyzabc34 wxyzab23) uvwxyz12 (123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzXabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90) opqrst89 ((123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89) mnopqr78 ((xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89 (uvwxyz12 stuvwx01 stuvwx01 qrstuv90 qrstuv90 opqrst89) mnopqr78) klmnop67) ijklmn56 (((123456ab xyzabc34 xyzabc34 wxyzab23 wxyzab23 uvwxyz12) stuvwx01 (xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89) mnopqr78 ((xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89 (uvwxyz12 stuvwx01 stuvwx01 qrstuv90 qrstuv90 opqrst89) mnopqr78) klmnop67 ((wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89 (uvwxyz12 stuvwx01 stuvwx01 qrstuv90 qrstuv90 opqrsXt89) mnopqr78 (stuvwx01 qrstuv90 qrstuv90 opqrst89 opqrst89 mnopqr78) klmnop67) ijklmn56) ghijkl45 (((xyzabc34 wxyzab23 wxyzab23 uvwxyz12 uvwxyz12 stuvwx01) qrstuv90 (wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89 (uvwxyz12 stuvwx01 stuvwx01 qrstuv90 qrstuv90 opqrst89) mnopqr78) klmnop67 ((wxyzab23 uvwxyz12 uvwxyz12 stuvwx01 stuvwx01 qrstuv90) opqrst89 (uvwxyz12 stuvwx01 stuvwx01 qrstuv90 qrstuv90 opqrst89) mnopqr78 (stuvwx01 qrstuv90 qrstuv90 opqrst89 opqrst89 mnopqr78) klmnop67) ijklmn56 ((uvwxyz12 stuvwx01 stuvwx01 qrstuv90 qrstuv90 opqrst89) mnopqr78 (stuvwx01 qrstuv90 qrstuv90 opqrst89 opqrst89 mnopqr78) klmnop67 (qrstuv90 opqrst89 opqrst89 mnopqr78 mnopqr78 klmnop67) ijklmn56) ghijkl45) efghij34) cdefgh23) abcdef12)
END_OF_FILE
if test 17118 -ne `wc -c <'gabriel-scheme/fprint.tst'`; then
    echo shar: \"'gabriel-scheme/fprint.tst'\" unpacked with wrong size!
fi
# end of 'gabriel-scheme/fprint.tst'
fi
if test -f 'gabriel-scheme/takr.sch' -a "${1}" != "-c" ; then 
  echo shar: Will not clobber existing file \"'gabriel-scheme/takr.sch'\"
else
echo shar: Extracting \"'gabriel-scheme/takr.sch'\" \(17539 characters\)
sed "s/^X//" >'gabriel-scheme/takr.sch' <<'END_OF_FILE'
X;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
X; File:         takr.sch
X; Description:  TAKR benchmark
X; Author:       Richard Gabriel
X; Created:      12-Apr-85
X; Modified:     12-Apr-85 10:12:43 (Bob Shaw)
X;               22-Jul-87 (Will Clinger)
X; Language:     Scheme
X; Status:       Public Domain
X;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
X 
X;;; TAKR  -- 100 function (count `em) version of TAK that tries to defeat cache
X;;; memory effects.  Results should be the same as for TAK on stack machines.
X;;; Distribution of calls is not completely flat.
X 
X(define (tak0 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak1 (tak37 (- x 1) y z)
X                 (tak11 (- y 1) z x)
X                 (tak17 (- z 1) x y)))))
X(define (tak1 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak2 (tak74 (- x 1) y z)
X                 (tak22 (- y 1) z x)
X                 (tak34 (- z 1) x y)))))
X(define (tak2 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak3 (tak11 (- x 1) y z)
X                 (tak33 (- y 1) z x)
X                 (tak51 (- z 1) x y)))))
X(define (tak3 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak4 (tak48 (- x 1) y z)
X                 (tak44 (- y 1) z x)
X                 (tak68 (- z 1) x y)))))
X(define (tak4 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak5 (tak85 (- x 1) y z)
X                 (tak55 (- y 1) z x)
X                 (tak85 (- z 1) x y)))))
X(define (tak5 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak6 (tak22 (- x 1) y z)
X                 (tak66 (- y 1) z x)
X                 (tak2 (- z 1) x y)))))
X(define (tak6 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak7 (tak59 (- x 1) y z)
X                 (tak77 (- y 1) z x)
X                 (tak19 (- z 1) x y)))))
X(define (tak7 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak8 (tak96 (- x 1) y z)
X                 (tak88 (- y 1) z x)
X                 (tak36 (- z 1) x y)))))
X(define (tak8 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak9 (tak33 (- x 1) y z)
X                 (tak99 (- y 1) z x)
X                 (tak53 (- z 1) x y)))))
X(define (tak9 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak10 (tak70 (- x 1) y z)
X                  (tak10 (- y 1) z x)
X                  (tak70 (- z 1) x y)))))
X(define (tak10 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak11 (tak7 (- x 1) y z)
X                  (tak21 (- y 1) z x)
X                  (tak87 (- z 1) x y)))))
X(define (tak11 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak12 (tak44 (- x 1) y z)
X                  (tak32 (- y 1) z x)
X                  (tak4 (- z 1) x y)))))
X(define (tak12 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak13 (tak81 (- x 1) y z)
X                  (tak43 (- y 1) z x)
X                  (tak21 (- z 1) x y)))))
X 
X(define (tak13 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak14 (tak18 (- x 1) y z)
X                  (tak54 (- y 1) z x)
X                  (tak38 (- z 1) x y)))))
X(define (tak14 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak15 (tak55 (- x 1) y z)
X                  (tak65 (- y 1) z x)
X                  (tak55 (- z 1) x y)))))
X(define (tak15 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak16 (tak92 (- x 1) y z)
X                  (tak76 (- y 1) z x)
X                  (tak72 (- z 1) x y)))))
X(define (tak16 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak17 (tak29 (- x 1) y z)
X                  (tak87 (- y 1) z x)
X                  (tak89 (- z 1) x y)))))
X(define (tak17 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak18 (tak66 (- x 1) y z)
X                  (tak98 (- y 1) z x)
X                  (tak6 (- z 1) x y)))))
X(define (tak18 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak19 (tak3 (- x 1) y z)
X                  (tak9 (- y 1) z x)
X                  (tak23 (- z 1) x y)))))
X(define (tak19 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak20 (tak40 (- x 1) y z)
X                  (tak20 (- y 1) z x)
X                  (tak40 (- z 1) x y)))))
X(define (tak20 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak21 (tak77 (- x 1) y z)
X                  (tak31 (- y 1) z x)
X                  (tak57 (- z 1) x y)))))
X(define (tak21 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak22 (tak14 (- x 1) y z)
X                  (tak42 (- y 1) z x)
X                  (tak74 (- z 1) x y)))))
X(define (tak22 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak23 (tak51 (- x 1) y z)
X                  (tak53 (- y 1) z x)
X                  (tak91 (- z 1) x y)))))
X(define (tak23 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak24 (tak88 (- x 1) y z)
X                  (tak64 (- y 1) z x)
X                  (tak8 (- z 1) x y)))))
X(define (tak24 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak25 (tak25 (- x 1) y z)
X                  (tak75 (- y 1) z x)
X                  (tak25 (- z 1) x y)))))
X(define (tak25 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak26 (tak62 (- x 1) y z)
X                  (tak86 (- y 1) z x)
X                  (tak42 (- z 1) x y)))))
X(define (tak26 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak27 (tak99 (- x 1) y z)
X                  (tak97 (- y 1) z x)
X                  (tak59 (- z 1) x y)))))
X(define (tak27 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak28 (tak36 (- x 1) y z)
X                  (tak8 (- y 1) z x)
X                  (tak76 (- z 1) x y)))))
X(define (tak28 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak29 (tak73 (- x 1) y z)
X                  (tak19 (- y 1) z x)
X                  (tak93 (- z 1) x y)))))
X(define (tak29 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak30 (tak10 (- x 1) y z)
X                  (tak30 (- y 1) z x)
X                  (tak10 (- z 1) x y)))))
X(define (tak30 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak31 (tak47 (- x 1) y z)
X                  (tak41 (- y 1) z x)
X                  (tak27 (- z 1) x y)))))
X(define (tak31 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak32 (tak84 (- x 1) y z)
X                  (tak52 (- y 1) z x)
X                  (tak44 (- z 1) x y)))))
X(define (tak32 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak33 (tak21 (- x 1) y z)
X                  (tak63 (- y 1) z x)
X                  (tak61 (- z 1) x y)))))
X(define (tak33 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak34 (tak58 (- x 1) y z)
X                  (tak74 (- y 1) z x)
X                  (tak78 (- z 1) x y)))))
X(define (tak34 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak35 (tak95 (- x 1) y z)
X                  (tak85 (- y 1) z x)
X                  (tak95 (- z 1) x y)))))
X(define (tak35 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak36 (tak32 (- x 1) y z)
X                  (tak96 (- y 1) z x)
X                  (tak12 (- z 1) x y)))))
X(define (tak36 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak37 (tak69 (- x 1) y z)
X                  (tak7 (- y 1) z x)
X                  (tak29 (- z 1) x y)))))
X(define (tak37 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak38 (tak6 (- x 1) y z)
X                  (tak18 (- y 1) z x)
X                  (tak46 (- z 1) x y)))))
X(define (tak38 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak39 (tak43 (- x 1) y z)
X                  (tak29 (- y 1) z x)
X                  (tak63 (- z 1) x y)))))
X(define (tak39 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak40 (tak80 (- x 1) y z)
X                  (tak40 (- y 1) z x)
X                  (tak80 (- z 1) x y)))))
X(define (tak40 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak41 (tak17 (- x 1) y z)
X                  (tak51 (- y 1) z x)
X                  (tak97 (- z 1) x y)))))
X(define (tak41 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak42 (tak54 (- x 1) y z)
X                  (tak62 (- y 1) z x)
X                  (tak14 (- z 1) x y)))))
X(define (tak42 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak43 (tak91 (- x 1) y z)
X                  (tak73 (- y 1) z x)
X                  (tak31 (- z 1) x y)))))
X(define (tak43 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak44 (tak28 (- x 1) y z)
X                  (tak84 (- y 1) z x)
X                  (tak48 (- z 1) x y)))))
X(define (tak44 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak45 (tak65 (- x 1) y z)
X                  (tak95 (- y 1) z x)
X                  (tak65 (- z 1) x y)))))
X(define (tak45 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak46 (tak2 (- x 1) y z)
X                  (tak6 (- y 1) z x)
X                  (tak82 (- z 1) x y)))))
X(define (tak46 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak47 (tak39 (- x 1) y z)
X                  (tak17 (- y 1) z x)
X                  (tak99 (- z 1) x y)))))
X(define (tak47 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak48 (tak76 (- x 1) y z)
X                  (tak28 (- y 1) z x)
X                  (tak16 (- z 1) x y)))))
X(define (tak48 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak49 (tak13 (- x 1) y z)
X                  (tak39 (- y 1) z x)
X                  (tak33 (- z 1) x y)))))
X(define (tak49 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak50 (tak50 (- x 1) y z)
X                  (tak50 (- y 1) z x)
X                  (tak50 (- z 1) x y)))))
X(define (tak50 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak51 (tak87 (- x 1) y z)
X                  (tak61 (- y 1) z x)
X                  (tak67 (- z 1) x y)))))
X(define (tak51 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak52 (tak24 (- x 1) y z)
X                  (tak72 (- y 1) z x)
X                  (tak84 (- z 1) x y)))))
X(define (tak52 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak53 (tak61 (- x 1) y z)
X                  (tak83 (- y 1) z x)
X                  (tak1 (- z 1) x y)))))
X(define (tak53 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak54 (tak98 (- x 1) y z)
X                  (tak94 (- y 1) z x)
X                  (tak18 (- z 1) x y)))))
X(define (tak54 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak55 (tak35 (- x 1) y z)
X                  (tak5 (- y 1) z x)
X                  (tak35 (- z 1) x y)))))
X(define (tak55 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak56 (tak72 (- x 1) y z)
X                  (tak16 (- y 1) z x)
X                  (tak52 (- z 1) x y)))))
X(define (tak56 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak57 (tak9 (- x 1) y z)
X                  (tak27 (- y 1) z x)
X                  (tak69 (- z 1) x y)))))
X(define (tak57 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak58 (tak46 (- x 1) y z)
X                  (tak38 (- y 1) z x)
X                  (tak86 (- z 1) x y)))))
X(define (tak58 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak59 (tak83 (- x 1) y z)
X                  (tak49 (- y 1) z x)
X                  (tak3 (- z 1) x y)))))
X(define (tak59 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak60 (tak20 (- x 1) y z)
X                  (tak60 (- y 1) z x)
X                  (tak20 (- z 1) x y)))))
X(define (tak60 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak61 (tak57 (- x 1) y z)
X                  (tak71 (- y 1) z x)
X                  (tak37 (- z 1) x y)))))
X(define (tak61 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak62 (tak94 (- x 1) y z)
X                  (tak82 (- y 1) z x)
X                  (tak54 (- z 1) x y)))))
X(define (tak62 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak63 (tak31 (- x 1) y z)
X                  (tak93 (- y 1) z x)
X                  (tak71 (- z 1) x y)))))
X(define (tak63 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak64 (tak68 (- x 1) y z)
X                  (tak4 (- y 1) z x)
X                  (tak88 (- z 1) x y)))))
X(define (tak64 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak65 (tak5 (- x 1) y z)
X                  (tak15 (- y 1) z x)
X                  (tak5 (- z 1) x y)))))
X(define (tak65 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak66 (tak42 (- x 1) y z)
X                  (tak26 (- y 1) z x)
X                  (tak22 (- z 1) x y)))))
X(define (tak66 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak67 (tak79 (- x 1) y z)
X                  (tak37 (- y 1) z x)
X                  (tak39 (- z 1) x y)))))
X(define (tak67 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak68 (tak16 (- x 1) y z)
X                  (tak48 (- y 1) z x)
X                  (tak56 (- z 1) x y)))))
X(define (tak68 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak69 (tak53 (- x 1) y z)
X                  (tak59 (- y 1) z x)
X                  (tak73 (- z 1) x y)))))
X(define (tak69 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak70 (tak90 (- x 1) y z)
X                  (tak70 (- y 1) z x)
X                  (tak90 (- z 1) x y)))))
X(define (tak70 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak71 (tak27 (- x 1) y z)
X                  (tak81 (- y 1) z x)
X                  (tak7 (- z 1) x y)))))
X(define (tak71 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak72 (tak64 (- x 1) y z)
X                  (tak92 (- y 1) z x)
X                  (tak24 (- z 1) x y)))))
X(define (tak72 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak73 (tak1 (- x 1) y z)
X                  (tak3 (- y 1) z x)
X                  (tak41 (- z 1) x y)))))
X(define (tak73 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak74 (tak38 (- x 1) y z)
X                  (tak14 (- y 1) z x)
X                  (tak58 (- z 1) x y)))))
X(define (tak74 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak75 (tak75 (- x 1) y z)
X                  (tak25 (- y 1) z x)
X                  (tak75 (- z 1) x y)))))
X(define (tak75 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak76 (tak12 (- x 1) y z)
X                  (tak36 (- y 1) z x)
X                  (tak92 (- z 1) x y)))))
X(define (tak76 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak77 (tak49 (- x 1) y z)
X                  (tak47 (- y 1) z x)
X                  (tak9 (- z 1) x y)))))
X(define (tak77 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak78 (tak86 (- x 1) y z)
X                  (tak58 (- y 1) z x)
X                  (tak26 (- z 1) x y)))))
X(define (tak78 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak79 (tak23 (- x 1) y z)
X                  (tak69 (- y 1) z x)
X                  (tak43 (- z 1) x y)))))
X(define (tak79 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak80 (tak60 (- x 1) y z)
X                  (tak80 (- y 1) z x)
X                  (tak60 (- z 1) x y)))))
X(define (tak80 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak81 (tak97 (- x 1) y z)
X                  (tak91 (- y 1) z x)
X                  (tak77 (- z 1) x y)))))
X(define (tak81 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak82 (tak34 (- x 1) y z)
X                  (tak2 (- y 1) z x)
X                  (tak94 (- z 1) x y)))))
X(define (tak82 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak83 (tak71 (- x 1) y z)
X                  (tak13 (- y 1) z x)
X                  (tak11 (- z 1) x y)))))
X(define (tak83 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak84 (tak8 (- x 1) y z)
X                  (tak24 (- y 1) z x)
X                  (tak28 (- z 1) x y)))))
X(define (tak84 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak85 (tak45 (- x 1) y z)
X                  (tak35 (- y 1) z x)
X                  (tak45 (- z 1) x y)))))
X(define (tak85 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak86 (tak82 (- x 1) y z)
X                  (tak46 (- y 1) z x)
X                  (tak62 (- z 1) x y)))))
X(define (tak86 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak87 (tak19 (- x 1) y z)
X                  (tak57 (- y 1) z x)
X                  (tak79 (- z 1) x y)))))
X(define (tak87 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak88 (tak56 (- x 1) y z)
X                  (tak68 (- y 1) z x)
X                  (tak96 (- z 1) x y)))))
X(define (tak88 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak89 (tak93 (- x 1) y z)
X                  (tak79 (- y 1) z x)
X                  (tak13 (- z 1) x y)))))
X(define (tak89 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak90 (tak30 (- x 1) y z)
X                  (tak90 (- y 1) z x)
X                  (tak30 (- z 1) x y)))))
X(define (tak90 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak91 (tak67 (- x 1) y z)
X                  (tak1 (- y 1) z x)
X                  (tak47 (- z 1) x y)))))
X(define (tak91 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak92 (tak4 (- x 1) y z)
X                  (tak12 (- y 1) z x)
X                  (tak64 (- z 1) x y)))))
X(define (tak92 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak93 (tak41 (- x 1) y z)
X                  (tak23 (- y 1) z x)
X                  (tak81 (- z 1) x y)))))
X(define (tak93 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak94 (tak78 (- x 1) y z)
X                  (tak34 (- y 1) z x)
X                  (tak98 (- z 1) x y)))))
X(define (tak94 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak95 (tak15 (- x 1) y z)
X                  (tak45 (- y 1) z x)
X                  (tak15 (- z 1) x y)))))
X(define (tak95 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak96 (tak52 (- x 1) y z)
X                  (tak56 (- y 1) z x)
X                  (tak32 (- z 1) x y)))))
X(define (tak96 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak97 (tak89 (- x 1) y z)
X                  (tak67 (- y 1) z x)
X                  (tak49 (- z 1) x y)))))
X(define (tak97 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak98 (tak26 (- x 1) y z)
X                  (tak78 (- y 1) z x)
X                  (tak66 (- z 1) x y)))))
X(define (tak98 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak99 (tak63 (- x 1) y z)
X                  (tak89 (- y 1) z x)
X                  (tak83 (- z 1) x y)))))
X(define (tak99 x y z)
X  (cond ((not (< y x)) z)
X        (else (tak0 (tak0 (- x 1) y z)
X                 (tak0 (- y 1) z x)
X                 (tak0 (- z 1) x y)))))
X 
X;;; call:  (tak0 18 12 6)
X 
X(run-benchmark "TAKR" (lambda () (tak0 18 12 6)))
X
END_OF_FILE
if test 17539 -ne `wc -c <'gabriel-scheme/takr.sch'`; then
    echo shar: \"'gabriel-scheme/takr.sch'\" unpacked with wrong size!
fi
# end of 'gabriel-scheme/takr.sch'
fi
echo shar: End of archive 2 \(of 2\).
cp /dev/null ark2isdone
MISSING=""
for I in 1 2 ; do
    if test ! -f ark${I}isdone ; then
	MISSING="${MISSING} ${I}"
    fi
done
if test "${MISSING}" = "" ; then
    echo You have unpacked both archives.
    rm -f ark[1-9]isdone
else
    echo You still need to unpack the following archives:
    echo "        " ${MISSING}
fi
##  End of shell archive.
exit 0
